+++
title = "Parsing date for a post which begins with a subheading"
date = 2017-09-11T14:32:00+00:00
tags = ["dates", "date", "closed"]
draft = false
+++

## The "CLOSED" state of this heading (which is nil) should be ignored {#the-closed-state-of-this-heading--which-is-nil--should-be-ignored}

This is a test for `ox-hugo` Issue #[87](https://github.com/kaushalmodi/ox-hugo/issues/87).
